@@ -14,15 +14,10 @@ if __name__ == "__main__":
         bearer_token=open("keys/twitter-bearer-token").read().strip(),
     )  # splitting means that it recursively splits a large text into sentences and analyzes each individually
 
-    scores = darthvader.news_summary(
-        *args,
-    )  # latest date to get news from
+    # """
+    scores = darthvader.news_summary(*args)  # latest date to get news from
     print("News\n--")
     pprint(scores)
-
-    scores = darthvader.twitter_summary(
-        *args,
-    )  # latest date to get news from
+    scores = darthvader.twitter_summary(*args, size=200)  # latest date to get news from
     print("\nTwitter\n--")
     pprint(scores)
-# """
